@@ -27,7 +27,7 @@
  * along with libtrace; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: format_pcapfile.c 1603 2010-07-15 23:42:23Z salcock $
+ * $Id: format_pcapfile.c 1664 2010-10-06 00:37:07Z salcock $
  *
  */
 
@@ -189,7 +189,10 @@ static int pcapfile_start_input(libtrace_t *libtrace)
 		assert(sizeof(DATA(libtrace)->header) > 0);
 		
 		if (err<1) {
-
+			if (err == 0) {
+				trace_set_err(libtrace, TRACE_ERR_INIT_FAILED,
+						"Reading pcap file header\n");
+			}
 			return -1;
 		}
 		
@@ -395,7 +398,7 @@ static int pcapfile_write_packet(libtrace_out_t *out,
 	
 	/* Silently discard RT metadata packets and packets with an
 	 * unknown linktype. */
-	if (linktype == TRACE_TYPE_METADATA || linktype == ~0U) {
+	if (linktype == TRACE_TYPE_NONDATA || linktype == ~0U) {
 		return 0;
 	}
 
@@ -407,6 +410,7 @@ static int pcapfile_write_packet(libtrace_out_t *out,
 			trace_set_err_out(out, 
 				TRACE_ERR_NO_CONVERSION,
 				"pcap does not support this format");
+			assert(0);
 			return -1;
 		}
 
@@ -659,7 +663,7 @@ static struct libtrace_eventobj_t pcapfile_event(libtrace_t *libtrace, libtrace_
 }
 
 static void pcapfile_help(void) {
-	printf("pcapfile format module: $Revision: 1603 $\n");
+	printf("pcapfile format module: $Revision: 1664 $\n");
 	printf("Supported input URIs:\n");
 	printf("\tpcapfile:/path/to/file\n");
 	printf("\tpcapfile:/path/to/file.gz\n");
@@ -670,7 +674,7 @@ static void pcapfile_help(void) {
 
 static struct libtrace_format_t pcapfile = {
 	"pcapfile",
-	"$Id: format_pcapfile.c 1603 2010-07-15 23:42:23Z salcock $",
+	"$Id: format_pcapfile.c 1664 2010-10-06 00:37:07Z salcock $",
 	TRACE_FORMAT_PCAPFILE,
 	NULL,				/* probe filename */
 	pcapfile_probe_magic,		/* probe magic */
