@@ -27,7 +27,7 @@
  * along with libtrace; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: libtrace.h.in 1578 2010-05-04 04:08:40Z perry $
+ * $Id: libtrace.h.in 1665 2010-11-23 21:34:17Z salcock $
  *
  */
 
@@ -42,7 +42,7 @@
  * @author Perry Lorier
  * @author Shane Alcock
  *
- * @version $Id: libtrace.h.in 1578 2010-05-04 04:08:40Z perry $
+ * @version $Id: libtrace.h.in 1665 2010-11-23 21:34:17Z salcock $
  *
  * This library provides a per packet interface into a trace file, or a live 
  * captures.  It supports ERF, DAG cards, PCAP, Linux and BSD native sockets,
@@ -141,14 +141,14 @@
 
 /** API version as 2 byte hex digits, eg 0xXXYYZZ */
 #define LIBTRACE_API_VERSION \
-            ((3<<16)|(0<<8)|(7))
+            ((3<<16)|(0<<8)|(8))
 
 /** Replaced with the current SVN revision number when 'make dist' is invoked
  *  to create a distributable tarball */
-#define LIBTRACE_SVN_REVISION 1652 
+#define LIBTRACE_SVN_REVISION 0
 
 /** DAG driver version installed on the current system */
-#define DAG_DRIVER_V "DAG not present"
+#define DAG_DRIVER_V ""
     
 #ifdef __cplusplus 
 extern "C" { 
@@ -500,6 +500,14 @@ typedef struct libtrace_ip6_ext
 	uint8_t len;	/**< Length of the current header */
 } PACKED libtrace_ip6_ext_t;
 
+typedef struct libtrace_ip6_frag 
+{
+	uint8_t nxt;	/**< Next header */
+	uint8_t res;	/**< Reserved */
+	uint16_t frag_off;	/**< Fragment Offset (includes M flag) */
+	uint32_t ident;	/** Fragment identification */
+} PACKED libtrace_ip6_frag_t;
+
 /** Generic IPv6 header structure
  *
  * @note The flow label field also includes the Version and Traffic Class
@@ -1997,6 +2005,23 @@ size_t trace_get_wire_length(const libtrace_packet_t *packet);
 DLLEXPORT SIMPLE_FUNCTION
 size_t trace_get_framing_length(const libtrace_packet_t *packet);
 
+/** Get the length of the original payload content of the packet (in bytes).
+ * @param packet	The packet to determine the payload length for
+ * @return The size of the packet payload (without headers). Returns 0 if
+ * unable to calculate payload length correctly.
+ *
+ * This function reports the amount of data that followed the transport header
+ * when the packet was originally captured, i.e. prior to any snapping. Best
+ * described as the wire length minus the packet headers. 
+ *
+ * Currently only supports some protocols and will return 0 if an unsupported
+ * protocol header is encountered, or if one of the headers is truncated. 
+ *
+ * @note Supports IPv4, IPv6, TCP, UDP and ICMP.
+ */ 
+DLLEXPORT SIMPLE_FUNCTION
+size_t trace_get_payload_length(const libtrace_packet_t *packet);
+
 /** Truncate ("snap") the packet to the suggested length
  * @param packet	The packet to truncate
  * @param size		The new length of the packet (in bytes)
