@@ -117,9 +117,6 @@
     char *file;
     element_t *el_list = NULL;
 
-    /* i didnt want these to be global, but i think they have to be? :/ */
-    static bitbuffer_t buffer = 0;
-    static int bits = 0;
 
 
 /* Enabling traces.  */
@@ -142,14 +139,14 @@
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 27 "parser.y"
+#line 24 "parser.y"
 {
     int intval;
     char *textval;
     element_t *ptr;
 }
 /* Line 187 of yacc.c.  */
-#line 153 "parser.c"
+#line 150 "parser.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -162,7 +159,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 166 "parser.c"
+#line 163 "parser.c"
 
 #ifdef short
 # undef short
@@ -449,8 +446,8 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    41,    41,    44,    45,    48,    73,    74,    77,    80,
-      81,    82,    83,    84,    85,    89,    93,   140
+       0,    38,    38,    41,    42,    45,    70,    71,    74,    77,
+      78,    79,    80,    81,    82,    86,    90,   137
 };
 #endif
 
@@ -1361,17 +1358,17 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 41 "parser.y"
+#line 38 "parser.y"
     { /*print_list(el_list);*/ }
     break;
 
   case 4:
-#line 45 "parser.y"
+#line 42 "parser.y"
     { }
     break;
 
   case 5:
-#line 48 "parser.y"
+#line 45 "parser.y"
     { 
 		node_t *n;
 		element_t *el;
@@ -1398,57 +1395,57 @@ yyreduce:
     break;
 
   case 6:
-#line 73 "parser.y"
+#line 70 "parser.y"
     { (yyval.intval) = BIGENDIAN; }
     break;
 
   case 7:
-#line 74 "parser.y"
+#line 71 "parser.y"
     { (yyval.intval) = LITTLEENDIAN; }
     break;
 
   case 8:
-#line 77 "parser.y"
+#line 74 "parser.y"
     { (yyval.intval) = yylval.intval; }
     break;
 
   case 9:
-#line 80 "parser.y"
+#line 77 "parser.y"
     { (yyval.intval) = DISPLAY_HEX; }
     break;
 
   case 10:
-#line 81 "parser.y"
+#line 78 "parser.y"
     { (yyval.intval) = DISPLAY_INT; }
     break;
 
   case 11:
-#line 82 "parser.y"
+#line 79 "parser.y"
     { (yyval.intval) = DISPLAY_IPV4; }
     break;
 
   case 12:
-#line 83 "parser.y"
+#line 80 "parser.y"
     { (yyval.intval) = DISPLAY_FLAG; }
     break;
 
   case 13:
-#line 84 "parser.y"
+#line 81 "parser.y"
     { (yyval.intval) = DISPLAY_MAC; }
     break;
 
   case 14:
-#line 85 "parser.y"
+#line 82 "parser.y"
     { (yyval.intval) = DISPLAY_NONE; }
     break;
 
   case 15:
-#line 89 "parser.y"
+#line 86 "parser.y"
     { (yyval.textval) = strdup((yyvsp[(1) - (1)].textval)); }
     break;
 
   case 16:
-#line 93 "parser.y"
+#line 90 "parser.y"
     { 
 
 		element_t *tmp;
@@ -1499,13 +1496,13 @@ yyreduce:
     break;
 
   case 17:
-#line 140 "parser.y"
+#line 137 "parser.y"
     { /*printf("no next file...\n");*/ (yyval.ptr) = NULL; }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1509 "parser.c"
+#line 1506 "parser.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1719,7 +1716,7 @@ yyreturn:
 }
 
 
-#line 144 "parser.y"
+#line 141 "parser.y"
 
 
 
